==> haskell-base-prelude-1.2.0.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-prelude
version: 1.2.0.1
id: base-prelude-1.2.0.1-HJh3WMXaeu8jTCoycvBYB
key: base-prelude-1.2.0.1-HJh3WMXaeu8jTCoycvBYB
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/base-prelude
synopsis: The most complete prelude formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    .
    This package will never have any dependencies other than \"base\".
    .
    /Versioning policy/
    .
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.
category: Prelude
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    BasePrelude
abi: 0de444933c1f946a6b18fe74d46e5131
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/base-prelude-1.2.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/base-prelude-1.2.0.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/base-prelude-1.2.0.1
hs-libraries: HSbase-prelude-1.2.0.1-HJh3WMXaeu8jTCoycvBYB
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock
haddock-html: /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-prelude-1.2.0.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-prelude
version: 1.2.0.1
id: base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT
key: base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/base-prelude
synopsis: The most complete prelude formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    .
    This package will never have any dependencies other than \"base\".
    .
    /Versioning policy/
    .
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.
category: Prelude
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    BasePrelude
abi: be7241d647b311157e69b90e57b06d24
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/base-prelude-1.2.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/base-prelude-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/base-prelude-1.2.0.1
hs-libraries: HSbase-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock
haddock-html: /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
